@@ -3,13 +3,15 @@ Main interface for sso-oidc service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.sso_oidc import SSOOIDCClient
+    from mypy_boto3_sso_oidc import SSOOIDCClient
 
     session = boto3.Session()
 
     client: SSOOIDCClient = boto3.client("sso-oidc")
     session_client: SSOOIDCClient = session.client("sso-oidc")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Any, Dict, List, TYPE_CHECKING, Type
